/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.message;

import java.util.Hashtable;
import java.util.Iterator;

import org.objectweb.dream.util.EmptyIterator;
import org.objectweb.dream.util.MultipleIterator;

/**
 */
public class BasicMessageTypeNC extends BasicMessageType
    implements
      MessageTypeNC
{

  Hashtable     namedSubMessageTypes    = null;
  String[]      subMessageNames         = null;
  MessageType[] allSubMessageTypesArray = null;

  /**
   * @see org.objectweb.dream.message.MessageTypeNC#getSubMessageType(java.lang.String)
   */
  public MessageType getSubMessageType(String name)
  {
    if (namedSubMessageTypes == null)
    {
      return null;
    }
    return (MessageType) namedSubMessageTypes.get(name);
  }

  /**
   * @see org.objectweb.dream.message.MessageTypeNC#getSubMessageNames()
   */
  public String[] getSubMessageNames()
  {
    if (subMessageNames == null)
    {
      if (namedSubMessageTypes == null)
      {
        subMessageNames = EMPTY_STRING_ARRAY;
      }
      else
      {
        subMessageNames = (String[]) namedSubMessageTypes.keySet().toArray(
            EMPTY_STRING_ARRAY);
      }
    }
    return subMessageNames;
  }

  /**
   * @see org.objectweb.dream.message.MessageTypeNC#getSubMessageNamesIterator()
   */
  public Iterator getSubMessageNamesIterator()
  {
    if (namedSubMessageTypes == null)
    {
      return EmptyIterator.INSTANCE;
    }
    return namedSubMessageTypes.keySet().iterator();
  }

  /**
   * Adds a sub Message type
   * 
   * @param messageName the name of the sub message type
   * @param messageType the sub message type
   * @throws MessageAlreadyExistException if this type already contains a sub
   *           message type with the specified name
   */
  public void addSubMessageType(String messageName, MessageType messageType)
      throws MessageAlreadyExistException
  {
    if (namedSubMessageTypes == null)
    {
      namedSubMessageTypes = new Hashtable();
      namedSubMessageTypes.put(messageName, messageType);
    }
    else
    {
      Object previousMessage = namedSubMessageTypes.put(messageName,
          messageType);
      if (previousMessage != null)
      {
        namedSubMessageTypes.put(messageName, previousMessage);
        throw new MessageAlreadyExistException();
      }
    }
    addSubMessageType(messageType);
  }

  /**
   * Removes a sub message type
   * 
   * @param subMessageName the name of the sub message type
   * @return the sub message type or <code>null</code> if no sub message type
   *         with the specified name exists.
   */
  public MessageType removeSubMessageType(String subMessageName)
  {
    if (namedSubMessageTypes == null)
    {
      return null;
    }
    MessageType t = (MessageType) namedSubMessageTypes.get(subMessageName);
    if (t != null)
    {
      removeSubMessageType(t);
      if (namedSubMessageTypes.isEmpty())
      {
        namedSubMessageTypes = null;
      }
    }
    return t;
  }

  /**
   * @see org.objectweb.dream.message.MessageType#getSubMessageTypes()
   */
  public MessageType[] getSubMessageTypes()
  {
    if (allSubMessageTypesArray == null)
    {
      if (subMessageTypes.isEmpty() && namedSubMessageTypes.isEmpty())
      {
        allSubMessageTypesArray = EMPTY_MESSAGE_TYPE_ARRAY;
      }
      else
      {
        allSubMessageTypesArray = new MessageType[subMessageTypes.size()
            + namedSubMessageTypes.size()];
        subMessageTypes.toArray(allSubMessageTypesArray);
        Iterator iter = namedSubMessageTypes.values().iterator();
        int i = subMessageTypes.size();
        while (iter.hasNext())
        {
          allSubMessageTypesArray[i] = (MessageType) iter.next();
          i++;
        }
      }
    }
    return subMessageTypesArray;
  }

  /**
   * @see org.objectweb.dream.message.MessageType#getSubMessageTypesIterator()
   */
  public Iterator getSubMessageTypesIterator()
  {
    return new MultipleIterator(new Iterator[]{subMessageTypes.iterator(),
        namedSubMessageTypes.values().iterator()});
  }

  /**
   * @see org.objectweb.dream.message.MessageTypeNC#getUnnamedSubMessageTypes()
   */
  public MessageType[] getUnnamedSubMessageTypes()
  {
    return super.getSubMessageTypes();
  }

  /**
   * @see org.objectweb.dream.message.MessageTypeNC#getUnnamedSubMessageTypesIterator()
   */
  public Iterator getUnnamedSubMessageTypesIterator()
  {
    return super.getSubMessageTypesIterator();
  }
}