/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.message;

/**
 * An interface that represent a chunk.
 * <p>
 * <b>WARNING </b>: this class is not designed to be implemented by every chunk
 * returned by {@link org.objectweb.dream.message.Message#getChunk(String)}.
 * But should be implemented by class implementing a single chunk interface, and
 * supposed to be used in extensible message
 */
public interface Chunk
{

  /**
   * Returns the id of the message manager that created this chunk.
   * 
   * @return the id of the message manager that created this chunk.
   */
  short getMessageManagerId();

  /**
   * Sets the id of the message manager that created this chunk.
   * 
   * @param messageManagerId the id to set.
   */
  void setMessageManagerId(short messageManagerId);

  /**
   * Returns the type of this chunk.
   * 
   * @return the type of this chunk.
   */
  ChunkType getType();

  /**
   * Transferts the state of this chunk into the specified new instance.
   * 
   * @param newInstance the new instance of chunk.
   */
  void transfertState(Chunk newInstance);

  /**
   * Recycles the chunk. This method must be called by message managers for the
   * chunk to be reusable.
   */
  void recycle();
}