/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Matthieu Leclercq
 */

package org.objectweb.dream.message;

/**
 * A component chunk type. Such a type is made of a list of method signatures,
 * which describes the methods provided by this chunk.
 */
public interface ChunkType
{

  /**
   * Returns the signatures of the methods provided by chunks of this type. In
   * Java this method returns the fully qualified name of a Java interface
   * corresponding to these method signatures.
   * 
   * @return the signatures of the methods provided by chunks of this type.
   */
  String getChunkSignature();

  /**
   * Returns <code>true</code> if this chunk type if a sub type of the given
   * chunk type.
   * 
   * @param t a chunk type
   * @return <code>true</code> if this chunk type if a sub type of the given
   *         chunk type.
   */
  boolean isSubTypeOf(ChunkType t);
}