/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.dream.message.chunk;

import org.objectweb.dream.message.BasicChunkType;
import org.objectweb.dream.message.ChunkType;

/**
 * A general purpose chunk that can be use to identify a sender and a receiver
 * of a message. The sender and the receiver are identified using a short
 * integer.
 */
public interface ArrowChunk
{

  /** The default name for chunks of this type */
  String    DEFAULT_NAME = "arrowChunk";

  /** The chunk type of chunks implementing this interface. */
  ChunkType TYPE         = new BasicChunkType(ArrowChunk.class,
                             BasicArrowChunk.class);

  /**
   * Returns the identifier of the sender.
   * 
   * @return the identifier of the sender.
   */
  short getArrowFrom();

  /**
   * Sets the identifier of the sender.
   * 
   * @param from the identifier of the sender.
   */
  void setArrowFrom(short from);

  /**
   * Returns the identifier of the receiver.
   * 
   * @return the identifier of the receiver.
   */
  short getArrowTo();

  /**
   * Sets the identifier of the receiver.
   * 
   * @param to the identifier of the receiver.
   */
  void setArrowTo(short to);
}