/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.message.codec;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.util.EmptyStringArray;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Codec repository implementation using a {@link Properties }to map codec name
 * with codec ADL. The content of the <code>Properties</code> object is
 * initialized by reading a properties file (see
 * {@link Properties#load(InputStream)}). The name of this file is given by the
 * attribute <code>PropertiesRessourceName</code> (see
 * {@link BasicCodecRepositoryAttributeController}). This attribute must be set
 * before the component is started.
 */
public class BasicCodecRepositoryImpl extends AbstractComponent
    implements
      CodecRepository,
      BasicCodecRepositoryAttributeController
{

  protected String     repositoryRessourceName;
  protected Properties repository;

  /**
   * @see CodecRepository#getCodecADL(String)
   */
  public String getCodecADL(String codecName)
  {
    return repository.getProperty(codecName);
  }

  // ---------------------------------------------------------------------------
  // Implementation of BasicCodecRepositoryAttributeController interface
  // ---------------------------------------------------------------------------

  /**
   * @see BasicCodecRepositoryAttributeController#getPropertiesRessourceName()
   */
  public String getPropertiesRessourceName()
  {
    return repositoryRessourceName;
  }

  /**
   * @see BasicCodecRepositoryAttributeController#setPropertiesRessourceName(String)
   */
  public void setPropertiesRessourceName(String name)
      throws CodecManagerException
  {
    InputStream is = ClassLoader.getSystemResourceAsStream(name);
    if (is == null)
    {
      throw new CodecManagerException(null, "Can't find properties file :"
          + name);
    }
    repository = new Properties();
    try
    {
      repository.load(is);
    }
    catch (IOException e)
    {
      throw new CodecManagerException(null,
          "Error while reading properties file : " + e.getLocalizedMessage());
    }
    repositoryRessourceName = name;
  }

  // ---------------------------------------------------------------------------
  // Implementation of BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return EmptyStringArray.EMPTY_STRING_ARRAY;
  }

  // ---------------------------------------------------------------------------
  // Implementation of LifeCycleControlle interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.LifeCycleController#startFc()
   */
  public void startFc() throws IllegalLifeCycleException
  {
    super.startFc();
    if (repository == null)
    {
      throw new IllegalLifeCycleException(
          "Properties Ressource Name attribute not set");
    }
  }
}