/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.message.manager;

import java.util.HashSet;
import java.util.Set;

import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.MessageType;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Extension of {@link PoolNonExtensibleMessageManagerImpl}that checks on every
 * message deletion that the deleted message is not already deleted. This can be
 * used for debug purpose.
 */
public class DebugPoolNonExtensibleMessageManagerImpl
    extends
      PoolNonExtensibleMessageManagerImpl
{

  Set deletedMessages = new HashSet();

  /**
   * @see PoolNonExtensibleMessageManagerImpl#deleteMessage(Message)
   */
  public synchronized void deleteMessage(Message message)
  {
    if (deletedMessages.contains(message))
    {
      logger.log(BasicLevel.ERROR, "Deleting message already deleted",
          new Exception());
      return;
    }
    super.deleteMessage(message);
  }

  /**
   * @see org.objectweb.dream.message.manager.PoolNonExtensibleMessageManagerImpl#createMessage(org.objectweb.dream.message.MessageType)
   */
  public synchronized Message createMessage(MessageType type)
      throws UnknownChunkTypeError
  {
    Message message = super.createMessage(type);
    deletedMessages.remove(message);
    return message;
  }
}